| lwbgt-package | R Documentation |
Dependency-free, vectorized access to the Liljegren outdoor wet bulb globe temperature numerical model.
Inputs use the same explicit field names and units as the native and Python interfaces. The package performs row-level validation and reports failures without aborting calculations for other rows.
Liljegren, J. C., Carhart, R. A., Lawday, P., Tschopp, S., and Sharp, R. (2008). Modeling the Wet Bulb Globe Temperature Using Standard Meteorological Measurements. Journal of Occupational and Environmental Hygiene, 5(10), 645–655. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/15459620802310770")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.